==> QupZilla-2.0.2.tar.xz: QupZilla-2.0.2/src/plugins/StatusBarIcons/translations/tr_TR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr_TR" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Site ve genel ayarlar yüklenirken yüklenen resmi nitele</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation>Aktif Sayfa Ayarları</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Resimleri yükleme (geçici)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Resimler yükle (geçici)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>Genel Ayarlar</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>Resimleri Otomatik Yükle</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Sitede ve genelde JavaScript ayarlarını nitele</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation>Aktif Sayfa Ayarları</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>JavaScripti Pasif Et (Geçici olarak)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>JavaScripti Aktif Et (geçici)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation>Genel Ayarlar</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>JavaScript Ayarlarını nitele</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="64"/>
        <source>Proxy Configuration</source>
        <translation>Vekil Sunucu Ayarları</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Select proxy</source>
        <translation>Proksi seç</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="80"/>
        <source>Empty</source>
        <translation>Boş</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Manage proxies</source>
        <translation>Proksileri yönet</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="97"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Ağ durumunu ve yönetilen proksileri yönetir&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Ağ:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proksi:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="100"/>
        <source>Connected</source>
        <translation>Bağlandı</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="103"/>
        <source>Offline</source>
        <translation>Çevrimdışı</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="108"/>
        <source>System proxy</source>
        <translation>Sistem proksisi</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>No proxy</source>
        <translation>Proksi yok</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>User defined</source>
        <translation>Kullanıcı tanımlı</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Proksi Yöneticisi</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Proksi seç: </translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>Proksi ekle</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Proksi sil</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Proksi yok. &lt;b&gt;Ekle&lt;/b&gt; düğmesine tıklayarak proksi ekleyebilirsiniz.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Tüm değişiklikler &lt;b&gt;Kaydet&lt;/b&gt; düğmesi ile kaydedilmelidir.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>Proksi ismi:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>Aktif proksiyi sil</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Biçim</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Durum Çubuğu Simgeleri</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Durum Çubuğu Simgeleri&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Bu simgeler durum çubuğunda gösterilecek:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Simge Resimleri</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>JavaScript Simgesi</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Ağ Simgesi</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>Yakınlaştırma aracı</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>Yakınlaştırma: %1%</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.0.tar.xz: QupZilla-2.2.0/src/plugins/StatusBarIcons/translations/tr_TR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr_TR" version="2.1">
<context>
    <name>SBI_ImagesIcon</name>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="32"/>
        <source>Modify images loading settings per-site and globally</source>
        <translation>Site ve genel ayarlar yüklenirken yüklenen resmi nitele</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="56"/>
        <source>Current Page Settings</source>
        <translation>Aktif Sayfa Ayarları</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="59"/>
        <source>Disable loading images (temporarily)</source>
        <translation>Resimleri yükleme (geçici)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="62"/>
        <source>Enable loading images (temporarily)</source>
        <translation>Resimler yükle (geçici)</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="66"/>
        <source>Global Settings</source>
        <translation>Genel Ayarlar</translation>
    </message>
    <message>
        <location filename="../sbi_imagesicon.cpp" line="68"/>
        <source>Automatically load images</source>
        <translation>Resimleri Otomatik Yükle</translation>
    </message>
</context>
<context>
    <name>SBI_JavaScriptIcon</name>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="33"/>
        <source>Modify JavaScript settings per-site and globally</source>
        <translation>Sitede ve genelde JavaScript ayarlarını nitele</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="50"/>
        <source>Current Page Settings</source>
        <translation>Aktif Sayfa Ayarları</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="53"/>
        <source>Disable JavaScript (temporarily)</source>
        <translation>JavaScripti Pasif Et (Geçici olarak)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="56"/>
        <source>Enable JavaScript (temporarily)</source>
        <translation>JavaScripti Aktif Et (geçici)</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="65"/>
        <source>Global Settings</source>
        <translation>Genel Ayarlar</translation>
    </message>
    <message>
        <location filename="../sbi_javascripticon.cpp" line="66"/>
        <source>Manage JavaScript settings</source>
        <translation>JavaScript Ayarlarını nitele</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIcon</name>
    <message>
        <location filename="../sbi_networkicon.cpp" line="64"/>
        <source>Proxy Configuration</source>
        <translation>Vekil Sunucu Ayarları</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="66"/>
        <source>Select proxy</source>
        <translation>Proksi seç</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="80"/>
        <source>Empty</source>
        <translation>Boş</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="84"/>
        <source>Manage proxies</source>
        <translation>Proksileri yönet</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="97"/>
        <source>Shows network status and manages proxy&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Network:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proxy:&lt;/b&gt;&lt;br/&gt;%2</source>
        <translation>Ağ durumunu ve yönetilen proksileri yönetir&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Ağ:&lt;/b&gt;&lt;br/&gt;%1&lt;br/&gt;&lt;br/&gt;&lt;b&gt;Proksi:&lt;/b&gt;&lt;br/&gt;%2</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="100"/>
        <source>Connected</source>
        <translation>Bağlandı</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="103"/>
        <source>Offline</source>
        <translation>Çevrimdışı</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="108"/>
        <source>System proxy</source>
        <translation>Sistem proksisi</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="112"/>
        <source>No proxy</source>
        <translation>Proksi yok</translation>
    </message>
    <message>
        <location filename="../sbi_networkicon.cpp" line="116"/>
        <source>User defined</source>
        <translation>Kullanıcı tanımlı</translation>
    </message>
</context>
<context>
    <name>SBI_NetworkIconDialog</name>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="14"/>
        <source>Proxy Manager</source>
        <translation>Proksi Yöneticisi</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="28"/>
        <source>Select proxy: </source>
        <translation>Proksi seç: </translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="38"/>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Add proxy</source>
        <translation>Proksi ekle</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="45"/>
        <source>Remove proxy</source>
        <translation>Proksi sil</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="69"/>
        <source>No proxies. You can add proxy by clicking on &lt;b&gt;Add&lt;/b&gt; button.</source>
        <translation>Proksi yok. &lt;b&gt;Ekle&lt;/b&gt; düğmesine tıklayarak proksi ekleyebilirsiniz.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.ui" line="104"/>
        <source>All changes must be saved with &lt;b&gt;Save&lt;/b&gt; button.</source>
        <translation>Tüm değişiklikler &lt;b&gt;Kaydet&lt;/b&gt; düğmesi ile kaydedilmelidir.</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="57"/>
        <source>Name of proxy:</source>
        <translation>Proksi ismi:</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Remove current proxy</source>
        <translation>Aktif proksiyi sil</translation>
    </message>
    <message>
        <location filename="../sbi_networkicondialog.cpp" line="70"/>
        <source>Are you sure you want to remove current proxy?</source>
        <translation>Aktif proksiyi silmek istediğinizden emin misiniz?</translation>
    </message>
</context>
<context>
    <name>SBI_ProxyWidget</name>
    <message>
        <location filename="../sbi_proxywidget.ui" line="14"/>
        <source>Form</source>
        <translation>Biçim</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="23"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="28"/>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="39"/>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="76"/>
        <source>Username:</source>
        <translation>Kullanıcı adı:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="86"/>
        <source>Password:</source>
        <translation>Parola:</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="111"/>
        <source>S&amp;ystem proxy configuration</source>
        <translation>S&amp;istem Vekil Sunucu Ayarı</translation>
    </message>
    <message>
        <location filename="../sbi_proxywidget.ui" line="118"/>
        <source>&amp;Manual configuration</source>
        <translation>&amp;El İle Yapılandırma</translation>
    </message>
</context>
<context>
    <name>SBI_SettingsDialog</name>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="14"/>
        <source>StatusBar Icons</source>
        <translation>Durum Çubuğu Simgeleri</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="48"/>
        <source>&lt;h3&gt;StatusBar Icons&lt;/h3&gt;</source>
        <translation>&lt;h3&gt;Durum Çubuğu Simgeleri&lt;/h3&gt;</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="70"/>
        <source>These icons will be displayed in statusbar:</source>
        <translation>Bu simgeler durum çubuğunda gösterilecek:</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="97"/>
        <source>Images Icon</source>
        <translation>Simge Resimleri</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="104"/>
        <source>JavaScript Icon</source>
        <translation>JavaScript Simgesi</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="111"/>
        <source>Network Icon</source>
        <translation>Ağ Simgesi</translation>
    </message>
    <message>
        <location filename="../sbi_settingsdialog.ui" line="118"/>
        <source>Zoom widget</source>
        <translation>Yakınlaştırma aracı</translation>
    </message>
</context>
<context>
    <name>SBI_ZoomWidget</name>
    <message>
        <location filename="../sbi_zoomwidget.cpp" line="47"/>
        <source>Zoom: %1%</source>
        <translation>Yakınlaştırma: %1%</translation>
    </message>
</context>
</TS>
